@@ -8,7 +8,7 @@
 #define __PSET_H
 
 /*
- * $Id: pset.h,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $
+ * $Id: pset.h,v 1.2 2003-03-09 19:27:08 steveg Exp $
  */
 
 #include <stdlib.h>
@@ -33,8 +33,7 @@ typedef struct __pset *pset_h ;
 pset_h pset_create( unsigned alloc_start, unsigned alloc_step );
 void pset_destroy( pset_h pset );
 
-__pset_pointer pset_insert   ( pset_h, const __pset_pointer ) ;
-void pset_delete( pset_h pset, __pset_pointer ptr );
+void pset_delete( pset_h pset, const __pset_pointer ptr );
 __pset_pointer pset_add( pset_h pset, const __pset_pointer ptr );
 
 /* These 2 are in ops.c   */
@@ -90,8 +89,6 @@ void psi_remove( psi_h iter );
       ( (iter)->current += (iter)->step, (iter)->step = 1,   \
                __psi_current( iter ) )
 
-#define psi_reset( iter, newpset )   (iter)->pset = (newpset)
-
 #define psi_destroy( iter )          free( (char *) iter )
 
 psi_h psi_create( pset_h pset );
