@@ -32,6 +32,8 @@ void cnf_free( struct configuration *confp )
    pset_destroy( sconfs ) ;
    if ( confp->cnf_defaults )
       sc_free( confp->cnf_defaults ) ;
+
+   CLEAR(*confp);
 }
 
 
@@ -48,7 +50,7 @@ struct service_config *cnf_extract( struct configuration *confp,
    {
       struct service_config *iscp = SCP( pset_pointer( stab, u ) ) ;
 
-      if ( ! EQ( scp->sc_id, iscp->sc_id ) || sc_different_confs( scp, iscp ) )
+      if ( ! EQ( SC_ID(scp), SC_ID(iscp) ) || sc_different_confs( scp, iscp ) )
          continue ;
 
       pset_remove_index( stab, u ) ;
@@ -97,7 +99,7 @@ status_e cnf_init( struct configuration *confp, int *fdp, psi_h *iterp )
    if ( ( pset = pset_create( 0, 0 ) ) == NULL )
    {
       msg( LOG_CRIT, func, "can't create service table" ) ;
-      (void) close( fd ) ;
+      (void) Sclose( fd ) ;
       return( FAILED ) ;
    }
 
@@ -105,7 +107,7 @@ status_e cnf_init( struct configuration *confp, int *fdp, psi_h *iterp )
    {
       msg( LOG_ERR, func, "can't allocate defaults service" ) ;
       pset_destroy( pset ) ;
-      (void) close( fd ) ;
+      (void) Sclose( fd ) ;
       return( FAILED ) ;
    }
 
@@ -114,7 +116,7 @@ status_e cnf_init( struct configuration *confp, int *fdp, psi_h *iterp )
       msg( LOG_ERR, func, "can't create service table iterator" ) ;
       sc_free( scp ) ;
       pset_destroy( pset ) ;
-      (void) close( fd ) ;
+      (void) Sclose( fd ) ;
       return( FAILED ) ;
    }
 
@@ -130,6 +132,7 @@ static void destroy_service( struct service *sp )
 {
    svc_deactivate( sp ) ;
    svc_free( sp ) ;
+   sp = NULL;
 }
 
 
@@ -152,12 +155,17 @@ unsigned cnf_start_services( struct configuration *confp )
       if ( ( sp = svc_new( scp ) ) == NULL )
       {
          sc_free( scp ) ;
+         scp = NULL;
          continue ;
       }
 
       if ( svc_activate( sp ) == FAILED )
       {
+         msg( LOG_ERR, func,
+            "Service %s failed to start and is deactivated.",
+               SVC_ID( sp ) ) ;
          svc_free( sp ) ;
+         scp = NULL;
          continue ;
       }
 
