@@ -167,7 +167,7 @@ static status_e service_fill( struct service_config *scp,
       SC_SPECIFY( scp, A_PER_SOURCE ) ;
    }
 
-#ifdef HAVE_DNSREGISTRATION
+#ifdef HAVE_MDNS
    if ( ! SC_SPECIFIED( scp, A_MDNS ) )
    {
       SC_MDNS(scp) = SC_SPECIFIED( def, A_MDNS ) ? SC_MDNS(def) : YES;
@@ -488,7 +488,7 @@ static void remove_disabled_services( struct configuration *confp )
 /*
  * Check if all required attributes have been specified
  */
-static status_e service_attr_check( const struct service_config *scp )
+static status_e service_attr_check( struct service_config *scp )
 {
    mask_t         necessary_and_specified ;
    mask_t         necessary_and_missing ;
@@ -632,6 +632,18 @@ static status_e check_entry( struct service_config *scp,
           */
          continue;
       }
+#if defined(HAVE_RPC_RPCENT_H) || defined(HAVE_NETDB_H)
+      if ( SC_IS_RPC( scp ) && SC_IS_RPC ( tmp_scp ) )
+      {
+         const struct rpc_data *rdp1 = SC_RPCDATA( scp ) ;
+         const struct rpc_data *rdp2 = SC_RPCDATA( tmp_scp ) ;
+         if ( rdp1->rd_program_number != rdp2->rd_program_number )
+           continue;
+        if ( rdp1->rd_min_version > rdp2->rd_max_version ||
+             rdp1->rd_max_version < rdp2->rd_min_version )
+          continue;
+      }
+#endif
       if (diff) 
          msg( LOG_ERR, func, 
          "service: %s id: %s is unique but its identical to "
@@ -685,6 +697,35 @@ static status_e check_entry( struct service_config *scp,
          return( FAILED ) ;
    }
 
+#ifdef LABELED_NET
+      if (SC_LABELED_NET(scp)) {
+         if ( SC_IS_INTERNAL( scp ) ) {
+            msg( LOG_ERR, func,
+               "Internal services cannot support labeled networking: %s",
+               SC_ID(scp) ) ;
+            return( FAILED ) ;
+         }
+         if ( SC_SOCKET_TYPE(scp) != SOCK_STREAM ) {
+            msg( LOG_ERR, func,
+               "Non-stream socket types cannot support labeled networking: %s",
+               SC_ID(scp) ) ;
+            return( FAILED ) ;
+         }
+         if ( SC_WAITS( scp ) ) {
+            msg( LOG_ERR, func,
+               "Tcp wait services cannot support labeled networking: %s",
+               SC_ID(scp) ) ;
+            return( FAILED ) ;
+         }
+         if ( SC_REDIR_ADDR( scp ) != NULL) {
+            msg( LOG_ERR, func,
+               "Redirected services cannot support labeled networking: %s",
+               SC_ID(scp) ) ;
+            return( FAILED ) ;
+         }
+      }
+#endif
+
    if ( SC_IS_MUXCLIENT( scp ) ) 
    {
 	   if ( !SC_IS_UNLISTED( scp ) )
