@@ -7,8 +7,13 @@
 extern char program_version[];
 extern struct program_state ps;
 extern int signals_pending[2];
-
+#ifdef __GNUC__
+__attribute__ ((noreturn))
+#endif
 void quit_program(void);
+#ifdef __GNUC__
+__attribute__ ((noreturn))
+#endif
 void terminate_program(void);
 
 #endif
