@@ -58,7 +58,8 @@ void redir_handler( struct server *serp )
    struct service *sp = SERVER_SERVICE( serp );
    struct service_config *scp = SVC_CONF( sp );
    int RedirDescrip = SERVER_FD( serp );
-   int maxfd, num_read, num_wrote=0, ret=0;
+   int maxfd;
+   ssize_t num_read, num_wrote=0, ret=0;
    unsigned int sin_len = 0;
    unsigned long bytes_in = 0, bytes_out = 0;
    int no_to_nagle = 1;
@@ -75,9 +76,9 @@ void redir_handler( struct server *serp )
    close_all_svc_descriptors();
 
    /* If it's a tcp service we are redirecting */
-   if( scp->sc_protocol.value == IPPROTO_TCP )
+   if( SC_PROTOVAL(scp) == IPPROTO_TCP )
    {
-      memcpy(&serveraddr, scp->sc_redir_addr, sizeof(serveraddr));
+      memcpy(&serveraddr, SC_REDIR_ADDR(scp), sizeof(serveraddr));
       if( serveraddr.sa_in.sin_family == AF_INET ) {
          sin_len = sizeof( struct sockaddr_in );
          RedirServerFd = socket(AF_INET, SOCK_STREAM, 0);
@@ -156,7 +157,7 @@ void redir_handler( struct server *serp )
             do {
                num_read = read(RedirDescrip,
                   buff, sizeof(buff));
-               if (num_read == -1 && errno == EINTR)
+               if (num_read == (ssize_t)-1 && errno == EINTR)
                   continue;
                if (num_read <= 0)
                   goto REDIROUT;
@@ -205,7 +206,7 @@ void redir_handler( struct server *serp )
          }
       }
 REDIROUT:
-      if( M_IS_SET( (scp)->sc_log_on_success, LO_TRAFFIC ) ) {
+      if( M_IS_SET( SC_LOG_ON_SUCCESS(scp), LO_TRAFFIC ) ) {
          svc_logprint( SERVER_CONNSERVICE( serp ), "TRAFFIC",
                        "in=%lu(bytes) out=%lu(bytes)", bytes_in, bytes_out );
       }
