@@ -3,6 +3,9 @@
 
 #include "server.h"
 
+#ifdef __GNUC__
+__attribute__ ((noreturn))
+#endif
 void redir_handler(struct server *serp);
 
 #endif
