@@ -20,8 +20,8 @@
 #include <errno.h>
 #include <netinet/in.h>
 #include <stdio.h>
-#ifdef HAVE_DNSREGISTRATION
-#include <DNSServiceDiscovery/DNSServiceDiscovery.h>
+#ifdef HAVE_MDNS
+#include "xmdns.h"
 #endif
 #ifndef NO_RPC
  #ifdef HAVE_RPC_PMAP_CLNT_H
@@ -162,7 +162,7 @@ static status_e set_fd_modes( struct service *sp )
 static status_e activate_rpc( struct service *sp )
 {
    union xsockaddr        tsin;
-   unsigned int           sin_len = sizeof(tsin);
+   socklen_t              sin_len = sizeof(tsin);
    unsigned long          vers ;
    struct service_config *scp = SVC_CONF( sp ) ;
    struct rpc_data       *rdp = SC_RPCDATA( scp ) ;
@@ -176,6 +176,9 @@ static status_e activate_rpc( struct service *sp )
    else
       memset( &tsin, 0, sizeof(tsin));
 
+   if ( SC_PROTOVAL ( scp ) == IPPROTO_TCP ) {
+      M_SET ( scp->sc_xflags, SF_NOLIBWRAP );
+   }
    if( SC_IPV4( scp ) ) {
       tsin.sa_in.sin_family = AF_INET ;
       sin_len = sizeof(struct sockaddr_in);
@@ -200,7 +203,7 @@ static status_e activate_rpc( struct service *sp )
       return( FAILED ) ;
    }
    
-   if( tsin.sa.sa_family == AF_INET ) 
+   if( tsin.sa.sa_family == AF_INET )
       SC_SET_PORT( scp, ntohs( tsin.sa_in.sin_port ) ) ;
    else if( tsin.sa.sa_family == AF_INET6 )
       SC_SET_PORT( scp, ntohs( tsin.sa_in6.sin6_port ) ) ;
@@ -232,13 +235,6 @@ static status_e activate_rpc( struct service *sp )
 
 #endif   /* ! NO_RPC */
 
-#ifdef HAVE_DNSREGISTRATION 
-static void mdns_callback(DNSServiceRegistrationReplyErrorType err, void *d)
-{
-	return;
-}
-#endif
-
 static status_e activate_normal( struct service *sp )
 {
    union xsockaddr         tsin;
@@ -308,6 +304,17 @@ static status_e activate_normal( struct service *sp )
       return( FAILED ) ;
    }
 
+#ifdef IN_MULTICAST
+   if( SC_IPV4(scp) && IN_MULTICAST(tsin.sa_in.sin_addr.s_addr) ) {
+      struct ip_mreq mreq;
+      mreq.imr_multiaddr.s_addr = tsin.sa_in.sin_addr.s_addr;
+      mreq.imr_interface.s_addr = htonl(INADDR_ANY);
+      setsockopt(sd, IPPROTO_IP, IP_ADD_MEMBERSHIP, &mreq, sizeof(mreq));
+      if ( debug.on )
+         msg( LOG_DEBUG, func, "Adding multicast membership." );
+   }
+#endif
+
    return( OK ) ;
 }
 
@@ -363,22 +370,8 @@ status_e svc_activate( struct service *sp )
       return( FAILED ) ;
    }
 
-#ifdef HAVE_DNSREGISTRATION
-   if ( SC_MDNS(scp) == YES )
-   {
-      if( SC_MDNSCON( SVC_CONF(sp) ) )
-         DNSServiceDiscoveryDeallocate( SC_MDNSCON(SVC_CONF(sp)) );
-      if( SC_MDNS_NAME(scp) )
-         free(SC_MDNS_NAME(scp));
-      if( asprintf(&SC_MDNS_NAME(scp), "_%s._%s", SC_NAME(scp), SC_PROTONAME(scp)) < 0 ) 
-      {
-          deactivate( sp );
-          return( FAILED );
-      }
-
-      SC_MDNSCON(scp) = DNSServiceRegistrationCreate("", SC_MDNS_NAME(scp), "", 
-		   htons(SC_PORT(scp)), "", mdns_callback, NULL);
-   }
+#ifdef HAVE_MDNS
+   xinetd_mdns_register(scp);
 #endif
 
    if ( log_start( sp, &SVC_LOG(sp) ) == FAILED )
@@ -414,9 +407,8 @@ static void deactivate( const struct service *sp )
 {
    (void) Sclose( SVC_FD( sp ) ) ;
 
-#ifdef HAVE_DNSREGISTRATION
-   if( SC_MDNSCON( SVC_CONF(sp) ) )
-      DNSServiceDiscoveryDeallocate( SC_MDNSCON(SVC_CONF(sp)) );
+#ifdef HAVE_MDNS
+   xinetd_mdns_deregister(SVC_CONF(sp));
 #endif
 
    if (debug.on)
@@ -629,7 +621,7 @@ static int banner_always( const struct service *sp, const connection_s *cp )
    /* print the banner regardless of access control */
    if ( SC_BANNER(scp) != NULL ) {
       char tmpbuf[TMPSIZE];
-      int retval;
+      ssize_t retval;
       int bannerfd = open(SC_BANNER(scp), O_RDONLY);
 
       if( bannerfd < 0 ) {
@@ -639,7 +631,7 @@ static int banner_always( const struct service *sp, const connection_s *cp )
       }
 
       while( (retval = read(bannerfd, tmpbuf, sizeof(tmpbuf))) ) {
-         if (retval == -1)
+         if (retval == (ssize_t)-1)
          {
             if (errno == EINTR)
                continue;
@@ -654,6 +646,7 @@ static int banner_always( const struct service *sp, const connection_s *cp )
       }
 
       Sclose(bannerfd);
+      Sflush ( cp->co_descriptor );
    }
 
    return(0);
@@ -694,6 +687,7 @@ static int banner_fail( const struct service *sp, const connection_s *cp )
       }
 
       Sclose(bannerfd);
+      Sflush ( cp->co_descriptor );
    }
 
    return(0);
@@ -732,6 +726,7 @@ static int banner_success( const struct service *sp, const connection_s *cp )
       }
 
       Sclose(bannerfd);
+      Sflush ( cp->co_descriptor );
    }
    return(0);
 }
@@ -764,8 +759,8 @@ static status_e failed_service(struct service *sp,
                return FAILED;
 
             if ( last == NULL ) {
-               last = SAIN( SVC_LAST_DGRAM_ADDR(sp) ) = 
-		  SAIN( calloc( 1, sizeof(union xsockaddr) ) );
+               last = SAIN( calloc( 1, sizeof(union xsockaddr) ) );
+	       SVC_LAST_DGRAM_ADDR(sp) = (union xsockaddr *)last;
             }
 
             (void) time( &current_time ) ;
@@ -791,8 +786,8 @@ static status_e failed_service(struct service *sp,
                return FAILED;
 
 	    if( last == NULL ) {
-               last = SAIN6(SVC_LAST_DGRAM_ADDR(sp)) = 
-		  SAIN6(calloc( 1, sizeof(union xsockaddr) ) );
+               last = SAIN6(calloc( 1, sizeof(union xsockaddr) ) );
+	       SVC_LAST_DGRAM_ADDR( sp ) = (union xsockaddr *)last;
             }
 
             (void) time( &current_time ) ;
@@ -890,7 +885,9 @@ void svc_postmortem( struct service *sp, struct server *serp )
             drain( cp->co_descriptor ) ;
          free(cp);
          cp = NULL;
-         SVC_RELE( sp );
+         if( SVC_RELE( sp ) == 0 )
+            svc_release( sp ); /* shouldn't be 0, but should remove from
+                                * pset if it is... */
       }
       svc_resume(sp);
    }
