@@ -36,7 +36,7 @@ static const struct builtin_service special_services[] =
       { LOG_SERVICE_NAME,        SOCK_STREAM,   { stream_logging,    FORK   } },
       { INTERCEPT_SERVICE_NAME,  SOCK_STREAM,   { intercept,         FORK   } },
       { INTERCEPT_SERVICE_NAME,  SOCK_DGRAM,    { intercept,         FORK   } },
-      { NULL }
+      { NULL,                    0,             { NULL,              0      } }
    } ;
 
 
@@ -62,19 +62,14 @@ const builtin_s *spec_find( const char *service_name, int type )
 }
 
 
-static status_e spec_service_handler( struct service *sp, connection_s *cp )
+status_e spec_service_handler( struct service *sp, connection_s *cp )
 {
-   if ( svc_parent_access_control( sp, cp ) == FAILED ||
-      svc_child_access_control( sp, cp ) == FAILED || 
-      server_run( sp, cp ) == FAILED )
-   {
-      return( FAILED ) ;
-   }
-   return( OK ) ;
+   return(server_run( sp, cp ));
 }
 
 
-static struct service *spec_setup( char *name, int socket_type, int instances )
+static struct service *spec_setup( const char *name, int socket_type, 
+                                   int instances )
 {
    const builtin_s *bp ;
    struct service_config *scp ;
@@ -86,7 +81,7 @@ static struct service *spec_setup( char *name, int socket_type, int instances )
    if ( ( scp = sc_make_special( name, bp, instances ) ) == NULL )
       return( NULL ) ;
 
-   return( svc_make_special( scp, spec_service_handler ) ) ;
+   return( svc_make_special( scp ) ) ;
 }
 
 
