@@ -9,7 +9,7 @@
 #define STATE_H
 
 /*
- * $Id: state.h,v 1.2 2003/05/31 15:03:52 steveg Exp $
+ * $Id: state.h,v 1.3 2005-03-30 23:15:28 bbraun Exp $
  */
 
 #include "config.h"
@@ -68,6 +68,9 @@ struct read_write_state
    xlog_h           program_log ;
    sigjmp_buf       env ;
    bool_int         env_is_valid ;
+#ifdef HAVE_MDNS
+   void            *mdns_state ;
+#endif
 } ;
 
 struct program_state
